body.template-discussion_reply_form .documentActions {
  display:none;
}

.blogView {
/*position: relative;*/
}

.classificationItem {
  padding-left:1em;
}

.blogView .actionsBarContent {
  padding:1em 1em 1.5em;
}

/* another exception for actionbar and edit menus */
.blogView .actionsBar {
  margin-top: -1.1em;
}
.blogView h1,
.blogView #dropdown-contentmenu {
  margin-left: 0 !important;
}

.portletBlogCategory .portletItem,
.portletTagcloud .portletItem {
  font-size: 1em;
}
.portletTagcloud .portletItem a {
  color: #76797c;
}

.blogView .blogImages a {
  border: 1px solid lightgrey;
  display: block;
  float: left;
  margin: 0.5em;
  padding: 1em;
}

.blogView a.show_all {
    display: block;
    padding: 0.5em 0;
}